UEDGE benchmark case
====================

Solves equations for
* density `Ni`
* parallel ion velocity `Vi`
* electron and ion temperatures `Te`, `Ti`

Intended to be run for `nz = 1` (i.e. `X` and `Y` only) for comparison with
[`UEDGE`](https://github.com/LLNL/UEDGE)
